@@ -4,7 +4,6 @@ import re
 import sys
 import textwrap
 from io import StringIO
-from typing import List
 
 import pytest
 
@@ -13,7 +12,7 @@ from check_python_versions.sources.base import SourceFile
 from check_python_versions.versions import Version
 
 
-def v(versions: List[str]) -> List[Version]:
+def v(versions: list[str]) -> list[Version]:
     return [Version.from_string(v) for v in versions]
 
 
@@ -86,8 +85,10 @@ def test_check_not_a_directory(tmp_path, capsys):
 
 def test_check_not_a_package(tmp_path, capsys):
     assert not cpv.check_package(tmp_path)
-    assert capsys.readouterr().out == 'no setup.py or pyproject.toml' \
-                                      ' -- not a Python package?\n'
+    assert capsys.readouterr().out == textwrap.dedent('''\
+        no setup.py or pyproject.toml -- not a Python package?
+        you may want to try --allow-non-packages
+    ''')
 
 
 def test_check_package(tmp_path):
